@@ -17,7 +17,6 @@
 #'  \item [route_cyclestreet()] - Finds the fastest routes for cyclists between two places.
 #' }
 #'
-#' @import rgdal
 #' @import curl
 #' @importFrom sp bbox plot spTransform Lines SpatialLines spChFIDs proj4string proj4string<- CRS coordinates
 #' @importFrom rgeos gBuffer gLength gIntersects gIntersection gArea gSimplify
@@ -39,4 +38,4 @@
 #' @importFrom dplyr first last n
 #' @useDynLib stplanr
 NULL
-utils::globalVariables(c(".", "n"))
+utils::globalVariables(c(".", "n", "matchingID"))
